# DRP Admin Panel

DRP Admin Panel is a [Composer](https://getcomposer.org/doc/00-intro.md) package for an Admin panel styled with
Bootstrap and useful widgets, based on AdminLTE https://github.com/almasaeed2010/AdminLTE with bonus user CRUD.

The purpose for this package is when you need a pretty admin panel in your shiny new Laravel (>5.0) project. We all got
tired of reimplementing the admin panel wheel and over-complicated / rubbish plugins so this is the drpdigital solution.

Think of this as a starter project - it makes more sense if you use it early on and extend this package if you're
adding a feature that could be useful for other projects.

Notable nice features:

- Bootstrap admin theme
- Admin menu with highlighting
- User Admin CRUD baked in
- Service Provider structure

Features to be add:
- Page of Admin panel widgets
- Demo admin view in example service provider


Copyright 2015 DRP (UK) Ltd.

### Client

Main contact is drp, who you should contact via Adam Cox.

Feel free to raise Feature Requests as GitLab issues to Alistair Buckle.

Please discuss enhancements with the Lead Developers and Merge Request to Alistair Buckle.


### Maintainers

- alistair.buckle@drpgroup.com **Lead Developer**
- chris.normansell@drproup.com Developer

## How to install
### Step #1
Add the repository to your composer.json.
```
{
    "repositories": [
        {
            "type": "composer",
            "url": "http://composer.drp.digital"
        }
    ]
}
```
### Step #2
Require the admin package into your project.
This will install the latest version.
```
composer require drp/drp-admin-panel
```
### Step #3
Add the admin panel service provider to your app config, located in `config/app.php`. I have listed below the Laravel 5.1 and 5.0 ways of adding a service provider.
#### Laravel 5.1
```
drp\AdminPanel\AdminPanelServiceProvider::class,
```
#### Laravel 5.0
```
'drp\AdminPanel\AdminPanelServiceProvider',
```
### Step #4
Setup your .env file so that the database settings are setup to your local environment. Also make sure you have the database created.

### Step #5
Run the setup command. This will guide you through setting up and integrating the package with your project.
```
php artisan admin:setup
```


## Coding Standards

- PHP: [PSR-2](https://github.com/php-fig/fig-standards/blob/master/accepted/PSR-2-coding-style-guide.md)
- Javascript: [Idomatic JavaScript](https://github.com/rwaldron/idiomatic.js/)
- CSS: [mdo CSS](http://codeguide.co/#css)
- HTML: [mdo HTML](http://codeguide.co/#html)

## Contributing
### Issues
Here are some top tips for making the issue assignee high five you upon submission:*

- User - What username did you use to login? Some information is differen't depending on your user.
- Device - E.g. iPhone, Windows Desktop, Windows Phone.
- Browser - E.g. Google Chrome, Internet Explorer, Firefox.
- Route (URL) - Shows where the issue occurs.
- Screenshot - Show the issue visually.
- Description - Explain what the issue is.
- Steps to reproduce - Detailed instructions to reproduce the issue, preferably in step-by-step format.

**high fives not guaranteed*

##### Branching
Create new branches from the current 'master' branch. When creating a branch make sure you include information that makes it easier to work with on the commandline.

{type}/#{num}-{brief-description-of-issue}

e.g.
- fix/#666-delete-the-devil
- feature/#123-make-it-as-easy-as-123

Submit a Merge Request to one of the maintainers and be ready for an exciting code review.
