<?php

namespace drp\AdminPanel;

use Illuminate\Support\ServiceProvider;

class AdminPanelServiceProvider extends ServiceProvider
{
    /**
     * Perform post-registration booting of services.
     *
     * @return void
     */
    public function boot()
    {
        $version = $this->app->version();

        $this->loadViewsFrom(realpath(__DIR__.'/../resources/views'), 'DrpAdmin');

        $this->publishes([
            __DIR__.'/../config/drpadmin.php' => config_path('drpadmin.php')
        ], 'config');

        $this->publishes([
            __DIR__ . '/../resources/assets/less/' => base_path('/resources/assets/drpadmin/less')
        ], 'less');

        $this->publishes([
            __DIR__ . '/../resources/assets/js/' => base_path('/resources/assets/drpadmin/js')
        ], 'js');

        $this->publishes([
            __DIR__ . '/../resources/assets/plugins' => public_path('drp-admin-panel/plugins')
        ], 'plugins');

        $this->publishes([
            __DIR__ . '/../gulp-tasks/' => base_path('/gulp-tasks')
        ], 'gulp-tasks');

        // Deciding which laravel version we are on and publishing the correct
        // elixir gulp file to match.
        if (version_compare($version, '5.1.0', '>=')) {
            $this->publishes([
                __DIR__ . '/../admin-elixir51.js' => base_path('/gulp-tasks/admin-elixir.js')
            ], 'gulp-tasks');
        } else {
            $this->publishes([
                __DIR__ . '/../admin-elixir50.js' => base_path('/gulp-tasks/admin-elixir.js')
            ], 'gulp-tasks');
        }
    }

    /**
     * Register any package services.
     *
     * @return void
     */
    public function register()
    {
        $this->app->register('Drp\AdminPanel\Sidebar\SidebarServiceProvider');
        $this->app->register('Drp\AdminPanel\Admin\AdminServiceProvider');
        // Only including user crud if the config allows it or there's no config.
        if (config('drpadmin.includeAdminUserCrud') || config('drpadmin') == false) {
            $this->app->register('Drp\AdminPanel\User\UserServiceProvider');
        }
        if (config('drpadmin.includeAdminStyleguide') || config('drpadmin') == false) {
            $this->app->register('Drp\AdminPanel\Styleguide\StyleguideServiceProvider');
        }

        $this->app->register('Drp\AdminPanel\Auth\AuthServiceProvider');
    }
}
