<?php

namespace Drp\AdminPanel\Sidebar;

abstract class SidebarItemBase
{
    /**
     * Icon to be displayed next to the sidebar text.
     *
     * @var string
     */
    protected $icon;

    /**
     * Base class to be added for the iconset.
     *
     * @var string
     */
    protected $iconBase;

    /**
     * Text to be displayed on the sidebar item.
     *
     * @var string
     */
    protected $text;

    /**
     * The callable to call to check whether to show this item.
     *
     * @var callable
     */
    protected $showCallable;

    /**
     * Constructor
     *
     * @param string   $icon         Icon to be displayed to the left of the text.
     * @param string   $text         Text to be displayed.
     * @param callable $showCallable Callable to test whether to show item.
     */
    public function __construct($icon, $text, $showCallable = null)
    {
        $this->icon = $icon;
        $this->iconBase = explode('-', $icon)[0];
        $this->text = $text;
        $this->showCallable = $showCallable;
    }

    /**
     * Returns whether this item should render.
     *
     * @return boolean
     */
    public function shouldRender()
    {
        if (is_callable($this->showCallable) === false) {
            return true;
        }

        return (boolean) call_user_func($this->showCallable);
    }

    /**
     * Gets the HTML for the icon.
     *
     * @return string
     */
    protected function getIconHtml()
    {
        return '<i class="' .
                    $this->iconBase . ' ' .
                    $this->icon .
                '"></i>';
    }
}
