<?php

namespace Drp\AdminPanel\User\Http\Controllers;

use Drp\AdminPanel\User\Repository\UserRepository;
use Drp\AdminPanel\User\Validation\UserValidator;
use Drp\AdminPanel\Admin\Http\Controllers\Controller;
use Illuminate\Http\Request;

class UserController extends Controller
{
    /**
     * @var UserValidator
     */
    protected $validator;

    /**
     * @var UserRepository
     */
    protected $repository;

    /**
     * Constructor
     *
     * @param UserValidator  $validator
     * @param UserRepository $repository
     */
    public function __construct(
        UserValidator $validator,
        UserRepository $repository
    ) {
        $this->validator  = $validator;
        $this->repository = $repository;

        parent::__construct();

        $this->data->pageTitle = 'Users';
    }

    /**
     * Index page for admin users.
     * GET /$baseRoutePath/users
     *
     * @return View
     */
    public function index()
    {
        $users = $this->repository->all();
        $this->data->users = $users;

        return view('DrpUserAdmin::index', $this->data);
    }

    /**
     * Create page for an admin user.
     * GET /$baseRoutePath/users/create
     *
     * @return View
     */
    public function create()
    {
        return view('DrpUserAdmin::create', $this->data);
    }

    /**
     * Edit page for an admin user
     *
     * @param  int $userId
     * @return View
     */
    public function edit($userId)
    {
        $user = $this->repository->getById($userId);
        $this->data->user = $user;

        return view('DrpUserAdmin::edit', $this->data);
    }

    public function store(Request $request)
    {
        $data = $request->all();
        $this->validator->setData($data);

        if ($this->validator->fails()) {
            return redirect()->back()
                ->withErrors($this->validator->errors()->getMessages())
                ->withInput();
        }

        $this->repository->store($data);

        return redirect()->route('admin.users.index')
            ->withSuccess('Successfully created user');
    }

    public function update(Request $request, $userId)
    {
        $data = $request->all();
        $this->validator->setData($data);

        if ($this->validator->fails()) {
            return redirect()->back()
                ->withErrors($this->validator->errors()->getMessages())
                ->withInput();
        }

        $this->repository->update($userId, $data);

        return redirect()->route('admin.users.index')
            ->withSuccess('Successfully updated user');
    }

    public function destroy($userId)
    {
        $this->repository->delete($userId);

        return redirect()->route('admin.users.index')
            ->withSuccess('Successfully deleted user');
    }
}
