<?php

namespace Drp\AdminPanel\User\Repository;


use DB;
use Hash;

class UserRepository
{
    /**
     * Empty instance of the admin user model.
     *
     * @var AdminUser
     */
    protected $model;

    /**
     * Constructor
     *
     * @param AdminUser $user
     */
    public function __construct(AdminUser $user)
    {
        $this->model = $user;
    }

    /**
     * Gets all the user models.
     *
     * @return Collection
     */
    public function all()
    {
        return $this->model->get();
    }

    /**
     * Gets a user by its id.
     *
     * @param  int       $userId
     * @return AdminUser
     */
    public function getById($userId)
    {
        $query = $this->model->where('id', $userId);

        return $query->first();
    }

    /**
     * Stores a new user
     *
     * @param array $data
     */
    public function store(array $data)
    {
        $newUser          = new $this->model();
        $data['password'] = $this->hashPassword($data['password']);
        $newUser->fill($data);
        $newUser->save();
    }

    /**
     * Updates an existing user.
     *
     * @param array $data
     */
    public function update($userId, array $data)
    {
        $user = $this->getById($userId);

        if (isset($data['password'])) {
            $password = $user->password;
            if ($data['password'] != '') {
                $password = $this->hashPassword($data['password']);
            }
            $data['password'] = $password;
        }

        $user->update($data);
    }

    private function hashPassword($password)
    {
        return Hash::make($password);
    }

    /**
     * Deletes a user by its id.
     *
     * @param int $userId
     */
    public function delete($userId)
    {
        $user = $this->getById($userId);
        $user->delete();
    }

    /**
     * Deletes all the users by truncating the table i.e. everything must go; id autoincrement zeroed; reset!
     */
    public function deleteAll()
    {
        DB::table($this->model->getTable())->truncate();
    }
}
